@@ -6,7 +6,7 @@ import pickle
 import random
 import struct
 from collections import defaultdict
-from dataclasses import asdict, dataclass
+from dataclasses import dataclass
 from datetime import datetime
 from typing import Any, ByteString, Callable, Iterator, List, Optional, Tuple, Union
 
@@ -336,11 +336,11 @@ class FReadDB:
         buff_limit: int = LMDB_BUFF_LIMIT,
         split_subdatabases=False,
     ):
-
-        self.db_file = db_file
+        db_file_name = db_file.split("/")[-1]
+        self.db_file = db_file + f"/{db_file_name}"
         create_dir(self.db_file)
 
-        self.metadata_file = db_file + ".json"
+        self.metadata_file = self.db_file + "_metadata.json"
         create_dir(self.metadata_file)
 
         if readonly and not os.path.exists(self.db_file) and not split_subdatabases:
@@ -366,7 +366,7 @@ class FReadDB:
 
     def save_metadata_info(self, db_schema: List[DBSpec], buff_limit: int):
         json_obj = {
-            "db_schema": [asdict(db_i) for db_i in db_schema],
+            "db_schema": [dataclasses.asdict(db_i) for db_i in db_schema],
             "buff_limit": buff_limit,
         }
         save_json_file(self.metadata_file, json_obj)
@@ -507,7 +507,7 @@ class FReadDB:
             )
 
     def get_random_key(self, db_name) -> Any:
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+        db_schema = self.db_schema[db_name].__dict__
         with self.env[db_name].begin(db=self.dbs[db_name], write=False) as txn:
             random_index = random.randint(0, self.get_number_items_from(db_name))
             cur = txn.cursor()
@@ -522,7 +522,7 @@ class FReadDB:
     def get_iter_integerkey(
         self, db_name: str, from_i: int = 0, to_i: int = -1, get_values: bool = True
     ) -> Iterator:
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+        db_schema = self.db_schema[db_name].__dict__
         with self.env[db_name].begin(db=self.dbs[db_name], write=False) as txn:
             if to_i == -1:
                 to_i = self.get_number_items_from(db_name)
@@ -550,7 +550,7 @@ class FReadDB:
     def get_iter_with_prefix(
         self, db_name: str, prefix: Any, get_values=True
     ) -> Iterator:
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+        db_schema = self.db_schema[db_name].__dict__
 
         with self.env[db_name].begin(db=self.dbs[db_name], write=False) as txn:
             cur = txn.cursor()
@@ -575,7 +575,7 @@ class FReadDB:
                 cur.next()
 
     def is_available(self, db_name: str, key_obj: str) -> bool:
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+        db_schema = self.db_schema[db_name].__dict__
         with self.env[db_name].begin(db=self.dbs[db_name]) as txn:
             key_obj = serialize_key(key_obj, **db_schema)
             if key_obj:
@@ -588,7 +588,7 @@ class FReadDB:
         return False
 
     def get_value_byte_size(self, db_name: str, key_obj: Any) -> Union[int, None]:
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+        db_schema = self.db_schema[db_name].__dict__
         with self.env[db_name].begin(db=self.dbs[db_name], buffers=True) as txn:
             key_obj = serialize_key(key_obj, **db_schema)
             if key_obj:
@@ -601,7 +601,7 @@ class FReadDB:
             return None
 
     def get_values(self, db_name: str, key_objs: List, get_deserialize: bool = True):
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+        db_schema = self.db_schema[db_name].__dict__
         with self.env[db_name].begin(db=self.dbs[db_name], buffers=True) as txn:
             if isinstance(key_objs, numpy.ndarray):
                 key_objs = key_objs.tolist()
@@ -629,7 +629,7 @@ class FReadDB:
         return responds
 
     def get_value(self, db_name: str, key_obj: Any, get_deserialize: bool = True):
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+        db_schema = self.db_schema[db_name].__dict__
         with self.env[db_name].begin(db=self.dbs[db_name], buffers=True) as txn:
             key_obj = serialize_key(key_obj, **db_schema)
             responds = None
@@ -664,7 +664,7 @@ class FReadDB:
         from_i: int = 0,
         to_i: int = -1,
     ):
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+        db_schema = self.db_schema[db_name].__dict__
         if to_i == -1:
             to_i = self.get_number_items_from(db_name)
 
@@ -697,7 +697,7 @@ class FReadDB:
                     raise Exception
 
     def delete(self, db_name: str, key: Any, with_prefix: bool = False) -> Any:
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+        db_schema = self.db_schema[db_name].__dict__
         if not (
             isinstance(key, list) or isinstance(key, set) or isinstance(key, tuple)
         ):
@@ -819,7 +819,7 @@ class FReadDB:
         buff_limit=LMDB_BUFF_LIMIT,
     ) -> bool:
         db = self.dbs[db_name]
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+        db_schema = self.db_schema[db_name].__dict__
 
         buff = []
         p_bar = None
@@ -897,15 +897,20 @@ class FReadDB:
                 self.env[db_name],
                 self.dbs[db_name],
                 buff,
-                **dataclasses.asdict(self.db_schema[db_name]),
+                **self.db_schema[db_name].__dict__,
             )
         return True
 
-    def add(self, db_name, key, value) -> bool:
-        db_schema = dataclasses.asdict(self.db_schema[db_name])
+    def add_buff(
+        self, db_name: str, key: Any, value: Any, is_serialize_value: bool = True
+    ) -> bool:
+        if is_serialize_value:
+            value = serialize_value(value, **self.db_schema[db_name].__dict__)
+            self.buff_size += len(value)
+        else:
+            # Assign default size of value 40 bytes
+            self.buff_size += 40960
 
-        value = serialize_value(value, **db_schema)
-        self.buff_size += len(value)
         self.buff[db_name].append([key, value])
         if self.buff_size > self.buff_limit:
             self.save_buff()
@@ -914,3 +919,16 @@ class FReadDB:
             self.buff = defaultdict(list)
             self.buff_size = 0
         return True
+
+    def delete_buff(self, db_name: str, key: Any) -> bool:
+        found = -1
+        for i, (k, _) in enumerate(self.buff[db_name]):
+            if k == key:
+                found = i
+                break
+
+        if found >= 0:
+            del self.buff[db_name][found]
+            return True
+        else:
+            return False
